"""
Module to store common enum classes used by pastebin.
"""
from .expire import Expire
from .format import Format
from .type import Type
from .visibility import Visibility

__all__ = [
    "Expire",
    "Format",
    "Type",
    "Visibility",
]
